
# proces name
PROCESS_NAME=rlinetd

# inet server config
CONFIG_FILE=/etc/rlinetd.conf
CONFIG_FILE_UMASK=027

# inet server daemon executable file name
INETDAEMON=/usr/sbin/rlinetd

# addytional inet server daemon argumments
INETDAEMON_ARGS=

__ulimit_n=$(ulimit -n)
if [ "$__ulimit_n" -gt 1024 -o "$__ulimit_n" = "unlimited" ]; then
	DEFAULT_SERVICE_LIMITS="-n 1024"
fi

PREAMBLE="# This file is autogenerated from /etc/sysconfig/rc-inetd!"

parse_one_service()
{
	ERROR_CODE=0

	[ ${SERVICE_NAME:-not} = "not" ]	&& ERROR_CODE=11
	[ ${PROTOCOL:-not} = "not" ]		&& ERROR_CODE=12
	if [ ${RPCNAME:-not} = "not" ]; then
		[ ${PORT:-not} = "not" ]	&& ERROR_CODE=13
	fi
	[ ${USER:-not} = "not" ]		&& ERROR_CODE=14
	[ ${SERVER:-not} = "not" ]		&& ERROR_CODE=15
	[ ${FLAGS:-not} = "not" ]		&& ERROR_CODE=16
	[ ${DAEMON:-not} = "not" ]		&& ERROR_CODE=17

	if [ ! $ERROR_CODE -eq 0 ] ; then
		echo "ERROR: Parse error."
		case "$ERROR_CODE" in
			11)
				echo "SERVICE_NAME not defined in /etc/sysconfig/rc-inetd/$CURRENT_SERVICE."
				;;
			12)
				echo "PROTOCOL not defined in /etc/sysconfig/rc-inetd/$CURRENT_SERVICE."
				;;
			13)
				echo "PORT not defined in /etc/sysconfig/rc-inetd/$CURRENT_SERVICE."
				;;
			14)
				echo "USER not defined in /etc/sysconfig/rc-inetd/$CURRENT_SERVICE."
				;;
			15)
				echo "SERVER not defined in /etc/sysconfig/rc-inetd/$CURRENT_SERVICE."
				;;
			16)
				echo "FLAGS not defined in /etc/sysconfig/rc-inetd/$CURRENT_SERVICE."
				;;
			17)
				echo "DAEMON not defined in /etc/sysconfig/rc-inetd/$CURRENT_SERVICE."
				;;
		esac
		return $ERROR_CODE
	fi

	echo "service \"$SERVICE_NAME\" {"
	echo "	protocol	$PROTOCOL;"
	[ "${FAMILY:-none}" = "none" ] || echo "	family		$FAMILY;"
	[ "${PORT:-none}" = "none" ] || echo "	port		\"$PORT\";"
	echo "	user		\"$USER\";"
	[ "${GROUP:-none}" = "none" ] || echo "	group		\"$GROUP\";"
	if [ "$SERVER" = "tcpd" ] ; then
		echo "	tcpd		{ exit; }"
	else
		echo "	server		\"$SERVER\";"
	fi
	echo -n "	exec		\"$DAEMON"
	if [ "${DAEMONARGS:-none}" = "none" ] ; then
		echo "\";"
	else
		echo " $DAEMONARGS\";"
	fi
	if [ "$FLAGS" = "wait" ] ; then
	echo "	wait		yes;"
	else
		[ "${MAX_CONNECTIONS:-n}" = "n" ] || echo "	instances	$MAX_CONNECTIONS;"
	fi

	[ "${INTERFACE:-n}" = "n" ]	|| echo "	interface	$INTERFACE;"
	[ "${NICE:-n}" = "n" ]		|| echo "	nice		$NICE;"
	if [ "${RPCNAME:-n}" != "n" ] ; then
		if [ "${RPCVERSION:-n}" != "n" ] ; then
			echo "	rpc {"
			echo "			name \"$RPCNAME\" ; version $RPCVERSION;"
			echo "	}"
		else
			return 2
		fi
	fi
	[ "${CHROOT:-n}" = "n" ]	|| echo "	chroot		\"$CHROOT\";"
	[ "${INITGROUPS:-n}" = "n" ]	|| echo "	initgroups;"
	[ "${BANNER:-n}" = "n" ]	|| echo "	banner		\"$BANNER\";"
	[ "${FILTER:-n}" = "n" ]	|| echo "	filer		\"$FILTER\";"
	[ "${ECHO:-n}" = "n" ]		|| echo "	echo		\"$ECHO\";"
	echo "}"

	return 0
}

status_rc_inetd()
{
	status $INETDAEMON
}

reload_config()
{
	killall -HUP $INETDAEMON
}
